@@ -1,11 +1,11 @@
 /* Copyright 2003-2004 Roger Dingledinex
  * Copyright 2004-2007 Roger Dingledine, Nick Mathewson */
 /* See LICENSE for licensing information */
-/* $Id: compat.h 9691 2007-02-28 21:07:19Z nickm $ */
+/* $Id: compat.h 10301 2007-05-24 15:48:53Z nickm $ */
 
 #ifndef __COMPAT_H
 #define __COMPAT_H
-#define COMPAT_H_ID "$Id: compat.h 9691 2007-02-28 21:07:19Z nickm $"
+#define COMPAT_H_ID "$Id: compat.h 10301 2007-05-24 15:48:53Z nickm $"
 
 #include "orconfig.h"
 #include "torint.h"
@@ -154,6 +154,14 @@ int tor_vsnprintf(char *str, size_t size, const char *format, va_list args)
 const void *tor_memmem(const void *haystack, size_t hlen, const void *needle,
                        size_t nlen)  ATTR_PURE ATTR_NONNULL((1,3));
 
+static const void *tor_memstr(const void *haystack, size_t hlen,
+                           const char *needle) ATTR_PURE ATTR_NONNULL((1,3));
+static INLINE const void *
+tor_memstr(const void *haystack, size_t hlen, const char *needle)
+{
+  return tor_memmem(haystack, hlen, needle, strlen(needle));
+}
+
 #define TOR_ISALPHA(c)   isalpha((int)(unsigned char)(c))
 #define TOR_ISALNUM(c)   isalnum((int)(unsigned char)(c))
 #define TOR_ISSPACE(c)   isspace((int)(unsigned char)(c))
