@@ -1,8 +1,8 @@
 /* Copyright (c) 2001 Matej Pfajfar.
  * Copyright (c) 2001-2004, Roger Dingledine.
- * Copyright (c) 2004-2006, Roger Dingledine, Nick Mathewson. */
+ * Copyright (c) 2004-2007, Roger Dingledine, Nick Mathewson. */
 /* See LICENSE for licensing information */
-/* $Id: crypto.h 8479 2006-09-24 17:20:41Z nickm $ */
+/* $Id: crypto.h 9570 2007-02-12 21:39:53Z nickm $ */
 
 /**
  * \file crypto.h
@@ -12,9 +12,10 @@
 
 #ifndef __CRYPTO_H
 #define __CRYPTO_H
-#define CRYPTO_H_ID "$Id: crypto.h 8479 2006-09-24 17:20:41Z nickm $"
+#define CRYPTO_H_ID "$Id: crypto.h 9570 2007-02-12 21:39:53Z nickm $"
 
 #include <stdio.h>
+#include "torint.h"
 
 /** Length of the output of our message digest. */
 #define DIGEST_LEN 20
@@ -79,8 +80,6 @@ int crypto_pk_read_public_key_from_string(crypto_pk_env_t *env,
                                           const char *src, size_t len);
 int crypto_pk_write_private_key_to_filename(crypto_pk_env_t *env,
                                             const char *fname);
-int crypto_pk_DER64_encode_public_key(crypto_pk_env_t *env, char **dest);
-crypto_pk_env_t *crypto_pk_DER64_decode_public_key(const char *in);
 
 int crypto_pk_check_key(crypto_pk_env_t *env);
 int crypto_pk_cmp_keys(crypto_pk_env_t *a, crypto_pk_env_t *b);
@@ -154,18 +153,22 @@ int crypto_expand_key_material(const char *key_in, size_t in_len,
 int crypto_seed_rng(void);
 int crypto_rand(char *to, size_t n);
 int crypto_rand_int(unsigned int max);
+uint64_t crypto_rand_uint64(uint64_t max);
 
 struct smartlist_t;
 void *smartlist_choose(const struct smartlist_t *sl);
 
 int base64_encode(char *dest, size_t destlen, const char *src, size_t srclen);
 int base64_decode(char *dest, size_t destlen, const char *src, size_t srclen);
+/** Characters that can appear (case-insensitively) in a base-32 encoding. */
 #define BASE32_CHARS "abcdefghijklmnopqrstuvwxyz234567"
 void base32_encode(char *dest, size_t destlen, const char *src, size_t srclen);
 
 int digest_to_base64(char *d64, const char *digest);
 int digest_from_base64(char *digest, const char *d64);
 
+/** Length of RFC2440-style S2K specifier: the first 8 bytes are a salt, the
+ * 9th describes how much iteration to do. */
 #define S2K_SPECIFIER_LEN 9
 void secret_to_key(char *key_out, size_t key_out_len, const char *secret,
                    size_t secret_len, const char *s2k_specifier);
