@@ -1,7 +1,7 @@
 /* Copyright 2003 Roger Dingledine
  * Copyright 2004-2007 Roger Dingledine, Nick Mathewson */
 /* See LICENSE for licensing information */
-/* $Id: torint.h 9677 2007-02-28 16:56:07Z nickm $ */
+/* $Id: torint.h 10803 2007-07-12 16:17:12Z nickm $ */
 
 /**
  * \file torint.h
@@ -10,7 +10,7 @@
 
 #ifndef __TORINT_H
 #define __TORINT_H
-#define TORINT_H_ID "$Id: torint.h 9677 2007-02-28 16:56:07Z nickm $"
+#define TORINT_H_ID "$Id: torint.h 10803 2007-07-12 16:17:12Z nickm $"
 
 #include "orconfig.h"
 
@@ -292,9 +292,9 @@ typedef uint32_t uintptr_t;
 
 #ifndef SIZE_T_MAX
 #if (SIZEOF_SIZE_T == 4)
-#define SIZE_T_MAX 0xfffffffful
+#define SIZE_T_MAX UINT32_MAX
 #elif (SIZEOF_SIZE_T == 8)
-#define SIZE_T_MAX 0xfffffffffffffffful
+#define SIZE_T_MAX UINT64_MAX
 #else
 #error "Can't define SIZE_T_MAX"
 #endif
