@@ -2,9 +2,9 @@
  * Copyright (c) 2001-2004, Roger Dingledine.
  * Copyright (c) 2004-2007, Roger Dingledine, Nick Mathewson. */
 /* See LICENSE for licensing information */
-/* $Id: circuitbuild.c 11274 2007-08-25 21:42:31Z arma $ */
+/* $Id: circuitbuild.c 11925 2007-10-14 08:48:48Z nickm $ */
 const char circuitbuild_c_id[] =
-  "$Id: circuitbuild.c 11274 2007-08-25 21:42:31Z arma $";
+  "$Id: circuitbuild.c 11925 2007-10-14 08:48:48Z nickm $";
 
 /**
  * \file circuitbuild.c
@@ -1723,9 +1723,11 @@ extend_info_from_router(routerinfo_t *r)
   extend_info_t *info;
   tor_assert(r);
   info = tor_malloc_zero(sizeof(extend_info_t));
-  strlcpy(info->nickname, r->nickname, sizeof(info->nickname));
+  if (r->nickname)
+    strlcpy(info->nickname, r->nickname, sizeof(info->nickname));
   memcpy(info->identity_digest, r->cache_info.identity_digest, DIGEST_LEN);
-  info->onion_key = crypto_pk_dup_key(r->onion_pkey);
+  if (r->onion_pkey)
+    info->onion_key = crypto_pk_dup_key(r->onion_pkey);
   info->addr = r->addr;
   info->port = r->or_port;
   return info;
@@ -1739,7 +1741,8 @@ extend_info_from_routerstatus(routerstatus_t *s)
   extend_info_t *info;
   tor_assert(s);
   info = tor_malloc_zero(sizeof(extend_info_t));
-  strlcpy(info->nickname, s->nickname, sizeof(info->nickname));
+  if (s->nickname)
+    strlcpy(info->nickname, s->nickname, sizeof(info->nickname));
   memcpy(info->identity_digest, s->identity_digest, DIGEST_LEN);
   info->onion_key = NULL; /* routerstatus doesn't know this */
   info->addr = s->addr;
@@ -2414,6 +2417,7 @@ entry_guards_parse_state(or_state_t *state, int set, char **msg)
   entry_guard_t *node = NULL;
   smartlist_t *new_entry_guards = smartlist_create();
   config_line_t *line;
+  time_t now = time(NULL);
 
   *msg = NULL;
   for (line = state->EntryGuards; line; line = line->next) {
@@ -2456,6 +2460,11 @@ entry_guards_parse_state(or_state_t *state, int set, char **msg)
                           "Bad time in EntryGuardDownSince/UnlistedSince");
         break;
       }
+      if (when > now) {
+        /* It's a bad idea to believe info in the future: you can wind
+         * up with timeouts that aren't allowed to happen for years. */
+        continue;
+      }
       if (strlen(line->value) >= ISO_TIME_LEN+ISO_TIME_LEN+1) {
         /* ignore failure */
         parse_iso_time(line->value+ISO_TIME_LEN+1, &last_try);
