@@ -2,9 +2,9 @@
  * Copyright (c) 2001-2004, Roger Dingledine.
  * Copyright (c) 2004-2007, Roger Dingledine, Nick Mathewson. */
 /* See LICENSE for licensing information */
-/* $Id: circuitlist.c 10814 2007-07-12 16:50:41Z nickm $ */
+/* $Id: circuitlist.c 11981 2007-10-16 13:59:34Z nickm $ */
 const char circuitlist_c_id[] =
-  "$Id: circuitlist.c 10814 2007-07-12 16:50:41Z nickm $";
+  "$Id: circuitlist.c 11981 2007-10-16 13:59:34Z nickm $";
 
 /**
  * \file circuitlist.c
@@ -779,10 +779,16 @@ circuit_find_to_cannibalize(uint8_t purpose, extend_info_t *info,
         if (info) {
           /* need to make sure we don't duplicate hops */
           crypt_path_t *hop = circ->cpath;
+          routerinfo_t *ri1 = router_get_by_digest(info->identity_digest);
           do {
+            routerinfo_t *ri2;
             if (!memcmp(hop->extend_info->identity_digest,
                         info->identity_digest, DIGEST_LEN))
               goto next;
+            if (ri1 &&
+                (ri2 = router_get_by_digest(hop->extend_info->identity_digest))
+                && routers_in_same_family(ri1, ri2))
+              goto next;
             hop=hop->next;
           } while (hop!=circ->cpath);
         }
@@ -1050,10 +1056,15 @@ assert_circuit_ok(const circuit_t *c)
   tor_assert(c->purpose >= _CIRCUIT_PURPOSE_MIN &&
              c->purpose <= _CIRCUIT_PURPOSE_MAX);
 
-  if (CIRCUIT_IS_ORIGIN(c))
-    origin_circ = TO_ORIGIN_CIRCUIT((circuit_t*)c);
-  else
-    or_circ = TO_OR_CIRCUIT((circuit_t*)c);
+  {
+    /* Having a separate variable for this pleases GCC 4.2 in ways I hope I
+     * never understand. -NM. */
+    circuit_t *nonconst_circ = (circuit_t*) c;
+    if (CIRCUIT_IS_ORIGIN(c))
+      origin_circ = TO_ORIGIN_CIRCUIT(nonconst_circ);
+    else
+      or_circ = TO_OR_CIRCUIT(nonconst_circ);
+  }
 
   if (c->n_conn) {
     tor_assert(!memcmp(c->n_conn->identity_digest, c->n_conn_id_digest,
