@@ -2,9 +2,9 @@
  * Copyright (c) 2001-2004, Roger Dingledine.
  * Copyright (c) 2004-2007, Roger Dingledine, Nick Mathewson. */
 /* See LICENSE for licensing information */
-/* $Id: connection.c 11135 2007-08-16 16:41:48Z nickm $ */
+/* $Id: connection.c 12402 2007-11-06 19:58:06Z nickm $ */
 const char connection_c_id[] =
-  "$Id: connection.c 11135 2007-08-16 16:41:48Z nickm $";
+  "$Id: connection.c 12402 2007-11-06 19:58:06Z nickm $";
 
 /**
  * \file connection.c
@@ -736,7 +736,7 @@ connection_handle_listener_read(connection_t *conn, int new_type)
   struct sockaddr_in remote;
   char addrbuf[256];
   /* length of the remote address. Must be whatever accept() needs. */
-  socklen_t remotelen = 256;
+  socklen_t remotelen = sizeof(addrbuf);
   char tmpbuf[INET_NTOA_BUF_LEN];
   tor_assert((size_t)remotelen >= sizeof(struct sockaddr_in));
   memset(addrbuf, 0, sizeof(addrbuf));
@@ -762,6 +762,16 @@ connection_handle_listener_read(connection_t *conn, int new_type)
             news,conn->s);
 
   set_socket_nonblocking(news);
+  if (((struct sockaddr*)addrbuf)->sa_family != AF_INET) {
+    log_info(LD_BUG, "A listener connection returned a socket with a "
+             "mismatched family.  %s for addr_family %d gave us a socket "
+             "with address family %d.  Dropping.",
+             conn_type_to_string(conn->type),
+             (int)AF_INET,
+             (int)((struct sockaddr*)addrbuf)->sa_family);
+    tor_close_socket(news);
+    return 0;
+  }
 
   if (check_sockaddr_in((struct sockaddr*)addrbuf, remotelen, LOG_INFO)<0) {
     log_info(LD_NET,
@@ -1318,15 +1328,19 @@ connection_bucket_refill(int seconds_elapsed)
 
   /* refill the global buckets */
   if (global_read_bucket < (int)options->BandwidthBurst) {
+    int initial_read_bucket = global_read_bucket;
     global_read_bucket += (int)options->BandwidthRate*seconds_elapsed;
-    if (global_read_bucket > (int)options->BandwidthBurst)
+    if (global_read_bucket > (int)options->BandwidthBurst ||
+        global_read_bucket < initial_read_bucket)
       global_read_bucket = (int)options->BandwidthBurst;
     log(LOG_DEBUG, LD_NET,"global_read_bucket now %d.", global_read_bucket);
   }
   if (global_write_bucket < (int)options->BandwidthBurst) {
+    int initial_write_bucket = global_write_bucket;
     global_write_bucket_empty_last_second = global_write_bucket == 0;
     global_write_bucket += (int)options->BandwidthRate*seconds_elapsed;
-    if (global_write_bucket > (int)options->BandwidthBurst)
+    if (global_write_bucket > (int)options->BandwidthBurst ||
+        global_write_bucket < initial_write_bucket)
       global_write_bucket = (int)options->BandwidthBurst;
     log(LOG_DEBUG, LD_NET,"global_write_bucket now %d.", global_write_bucket);
   }
@@ -1339,8 +1353,10 @@ connection_bucket_refill(int seconds_elapsed)
     if (connection_speaks_cells(conn)) {
       or_connection_t *or_conn = TO_OR_CONN(conn);
       if (connection_read_bucket_should_increase(or_conn)) {
+        int initial_read_bucket = or_conn->read_bucket;
         or_conn->read_bucket += or_conn->bandwidthrate*seconds_elapsed;
-        if (or_conn->read_bucket > or_conn->bandwidthburst)
+        if (or_conn->read_bucket > or_conn->bandwidthburst ||
+            or_conn->read_bucket < initial_read_bucket)
           or_conn->read_bucket = or_conn->bandwidthburst;
         //log_fn(LOG_DEBUG,"Receiver bucket %d now %d.", i,
         //       conn->read_bucket);
@@ -2279,6 +2295,9 @@ connection_finished_flushing(connection_t *conn)
 {
   tor_assert(conn);
 
+  if (conn->s < 0 || !conn->write_event)
+    return 0;
+
 //  log_fn(LOG_DEBUG,"entered. Socket %u.", conn->s);
 
   switch (conn->type) {
