@@ -1,9 +1,9 @@
 /* Copyright 2001-2004 Roger Dingledine.
  * Copyright 2004-2007 Roger Dingledine, Nick Mathewson. */
 /* See LICENSE for licensing information */
-/* $Id: directory.c 10808 2007-07-12 16:17:25Z nickm $ */
+/* $Id: directory.c 13055 2008-01-07 17:49:22Z nickm $ */
 const char directory_c_id[] =
-  "$Id: directory.c 10808 2007-07-12 16:17:25Z nickm $";
+  "$Id: directory.c 13055 2008-01-07 17:49:22Z nickm $";
 
 #include "or.h"
 
@@ -932,7 +932,7 @@ connection_dir_client_reached_eof(dir_connection_t *conn)
   }
   (void) skewed; /* skewed isn't used yet. */
 
-  if (status_code == 503) {
+  if (status_code == 503 && body_len < 16) {
     local_routerstatus_t *rs;
     trusted_dir_server_t *ds;
     time_t now = time(NULL);
@@ -947,6 +947,12 @@ connection_dir_client_reached_eof(dir_connection_t *conn)
 
     tor_free(body); tor_free(headers); tor_free(reason);
     return -1;
+  } else if (status_code == 503) {
+    /* XXXX022 Remove this once every server with bug 539 is obsolete. */
+    log_info(LD_DIR, "Server at '%s:%d' sent us a 503 response, but included "
+             "a body anyway.  We'll pretend it gave us a 200.",
+             conn->_base.address, conn->_base.port);
+    status_code = 200;
   }
 
   plausible = body_is_plausible(body, body_len, conn->_base.purpose);
@@ -1730,6 +1736,7 @@ directory_handle_command_get(dir_connection_t *conn, const char *headers,
                  "Client asked for server descriptors, but we've been "
                  "writing too many bytes lately. Sending 503 Dir busy.");
         write_http_status_line(conn, 503, "Directory busy, try again later");
+        conn->dir_spool_src = DIR_SPOOL_NONE;
         return 0;
       }
       write_http_response_header(conn, -1,
