@@ -2,9 +2,9 @@
  * Copyright (c) 2001-2004, Roger Dingledine.
  * Copyright (c) 2004-2007, Roger Dingledine, Nick Mathewson. */
 /* See LICENSE for licensing information */
-/* $Id: main.c 9744 2007-03-06 19:41:12Z arma $ */
+/* $Id: main.c 12629 2007-12-01 23:34:43Z arma $ */
 const char main_c_id[] =
-  "$Id: main.c 9744 2007-03-06 19:41:12Z arma $";
+  "$Id: main.c 12629 2007-12-01 23:34:43Z arma $";
 
 /**
  * \file main.c
@@ -747,6 +747,8 @@ run_scheduled_events(time_t now)
   static time_t time_to_try_getting_descriptors = 0;
   static time_t time_to_reset_descriptor_failures = 0;
   static time_t time_to_add_entropy = 0;
+#define CLEAN_CACHES_INTERVAL (30*60)
+  static time_t time_to_clean_caches = 0;
   or_options_t *options = get_options();
   int i;
   int have_dir_info;
@@ -854,12 +856,14 @@ run_scheduled_events(time_t now)
 /** How often do we (as a cache) fetch a new V1 runningrouters document? */
 #define V1_RUNNINGROUTERS_FETCH_PERIOD (30*60)
     time_to_fetch_running_routers = now + V1_RUNNINGROUTERS_FETCH_PERIOD;
+  }
 
-     /* Also, take this chance to remove old information from rephist
-     * and the rend cache. */
+  /* Remove old information from rephist and the rend cache. */
+  if (time_to_clean_caches < now) {
     rep_history_clean(now - options->RephistTrackTime);
     rend_cache_clean();
- }
+    time_to_clean_caches = now + CLEAN_CACHES_INTERVAL;
+  }
 
   /* 2b. Once per minute, regenerate and upload the descriptor if the old
    * one is inaccurate. */
@@ -1133,7 +1137,7 @@ dns_servers_relaunch_checks(void)
 }
 
 /** Called when we get a SIGHUP: reload configuration files and keys,
- * retry all connections, re-upload all descriptors, and so on. */
+ * retry all connections, and so on. */
 static int
 do_hup(void)
 {
@@ -1178,7 +1182,6 @@ do_hup(void)
 
   if (server_mode(options)) {
 //    const char *descriptor;
-    mark_my_descriptor_dirty();
     /* Restart cpuworker and dnsworker processes, so they get up-to-date
      * configuration options. */
     cpuworkers_rotate();
