@@ -1,8 +1,8 @@
 /* Copyright 2004-2007 Roger Dingledine, Nick Mathewson. */
 /* See LICENSE for licensing information */
-/* $Id: rephist.c 9634 2007-02-24 07:50:38Z arma $ */
+/* $Id: rephist.c 11925 2007-10-14 08:48:48Z nickm $ */
 const char rephist_c_id[] =
-  "$Id: rephist.c 9634 2007-02-24 07:50:38Z arma $";
+  "$Id: rephist.c 11925 2007-10-14 08:48:48Z nickm $";
 
 /**
  * \file rephist.c
@@ -719,6 +719,8 @@ rep_hist_load_state(or_state_t *state, char **err)
     if (s_values && s_begins >= now - NUM_SECS_BW_SUM_INTERVAL*NUM_TOTALS) {
       start = s_begins - s_interval*(smartlist_len(s_values));
 
+      if (start > now)
+        continue;
       b->cur_obs_time = start;
       b->next_period = start + NUM_SECS_BW_SUM_INTERVAL;
       SMARTLIST_FOREACH(s_values, char *, cp, {
@@ -727,8 +729,10 @@ rep_hist_load_state(or_state_t *state, char **err)
           all_ok=0;
           log_notice(LD_GENERAL, "Could not parse '%s' into a number.'", cp);
         }
-        add_obs(b, start, v);
-        start += NUM_SECS_BW_SUM_INTERVAL;
+        if (start < now) {
+          add_obs(b, start, v);
+          start += NUM_SECS_BW_SUM_INTERVAL;
+        }
       });
     }
 
