@@ -1,9 +1,9 @@
 /* Copyright 2001-2004 Roger Dingledine.
  * Copyright 2004-2007 Roger Dingledine, Nick Mathewson. */
 /* See LICENSE for licensing information */
-/* $Id: test.c 9681 2007-02-28 17:34:07Z nickm $ */
+/* $Id: test.c 12611 2007-11-30 07:49:49Z arma $ */
 const char test_c_id[] =
-  "$Id: test.c 9681 2007-02-28 17:34:07Z nickm $";
+  "$Id: test.c 12611 2007-11-30 07:49:49Z arma $";
 
 /**
  * \file test.c
@@ -1753,7 +1753,7 @@ test_policies(void)
           compare_addr_to_addr_policy(0xc0a80102, 2, policy));
 
   policy2 = NULL;
-  test_assert(0 == policies_parse_exit_policy(NULL, &policy2, 1));
+  test_assert(0 == policies_parse_exit_policy(NULL, &policy2, 1, NULL));
   test_assert(policy2);
 
   test_assert(!exit_policy_is_general_exit(policy));
@@ -1773,7 +1773,7 @@ test_policies(void)
   line.key = (char*)"foo";
   line.value = (char*)"accept *:80,reject private:*,reject *:*";
   line.next = NULL;
-  test_assert(0 == policies_parse_exit_policy(&line, &policy, 0));
+  test_assert(0 == policies_parse_exit_policy(&line, &policy, 0, NULL));
   test_assert(policy);
   test_streq(policy->string, "accept *:80");
   test_streq(policy->next->string, "reject *:*");
@@ -1815,7 +1815,7 @@ test_rend_fns(void)
   test_assert(!crypto_pk_cmp_keys(d1->pk, d2->pk));
   test_eq(d2->timestamp, now);
   test_eq(d2->version, 0);
-  test_eq(d2->protocols, 1);
+  test_eq(d2->protocols, 4);
   test_eq(d2->n_intro_points, 3);
   test_streq(d2->intro_points[0], "tom");
   test_streq(d2->intro_points[1], "crow");
